Class: Google::Apis::TestingV1::AndroidRoboTest
- Inherits:
-
Object
- Object
- Google::Apis::TestingV1::AndroidRoboTest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb
Overview
A test of an android application that explores the application on a virtual or physical Android Device, finding culprits and crashes as it goes.
Instance Attribute Summary collapse
-
#app_apk ⇒ Google::Apis::TestingV1::FileReference
A reference to a file, used for user inputs.
-
#app_bundle ⇒ Google::Apis::TestingV1::AppBundle
An Android App Bundle file format, containing a BundleConfig.pb file, a base module directory, zero or more dynamic feature module directories.
-
#app_initial_activity ⇒ String
The initial activity that should be used to start the app.
-
#app_package_id ⇒ String
The java package for the application under test.
-
#max_depth ⇒ Fixnum
The max depth of the traversal stack Robo can explore.
-
#max_steps ⇒ Fixnum
The max number of steps Robo can execute.
-
#robo_directives ⇒ Array<Google::Apis::TestingV1::RoboDirective>
A set of directives Robo should apply during the crawl.
-
#robo_mode ⇒ String
The mode in which Robo should run.
-
#robo_script ⇒ Google::Apis::TestingV1::FileReference
A reference to a file, used for user inputs.
-
#starting_intents ⇒ Array<Google::Apis::TestingV1::RoboStartingIntent>
The intents used to launch the app for the crawl.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AndroidRoboTest
constructor
A new instance of AndroidRoboTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AndroidRoboTest
Returns a new instance of AndroidRoboTest.
467 468 469 |
# File 'lib/google/apis/testing_v1/classes.rb', line 467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_apk ⇒ Google::Apis::TestingV1::FileReference
A reference to a file, used for user inputs.
Corresponds to the JSON property appApk
410 411 412 |
# File 'lib/google/apis/testing_v1/classes.rb', line 410 def app_apk @app_apk end |
#app_bundle ⇒ Google::Apis::TestingV1::AppBundle
An Android App Bundle file format, containing a BundleConfig.pb file, a base
module directory, zero or more dynamic feature module directories. See https://
developer.android.com/guide/app-bundle/build for guidance on building App
Bundles.
Corresponds to the JSON property appBundle
418 419 420 |
# File 'lib/google/apis/testing_v1/classes.rb', line 418 def app_bundle @app_bundle end |
#app_initial_activity ⇒ String
The initial activity that should be used to start the app.
Corresponds to the JSON property appInitialActivity
423 424 425 |
# File 'lib/google/apis/testing_v1/classes.rb', line 423 def app_initial_activity @app_initial_activity end |
#app_package_id ⇒ String
The java package for the application under test. The default value is
determined by examining the application's manifest.
Corresponds to the JSON property appPackageId
429 430 431 |
# File 'lib/google/apis/testing_v1/classes.rb', line 429 def app_package_id @app_package_id end |
#max_depth ⇒ Fixnum
The max depth of the traversal stack Robo can explore. Needs to be at least 2
to make Robo explore the app beyond the first activity. Default is 50.
Corresponds to the JSON property maxDepth
435 436 437 |
# File 'lib/google/apis/testing_v1/classes.rb', line 435 def max_depth @max_depth end |
#max_steps ⇒ Fixnum
The max number of steps Robo can execute. Default is no limit.
Corresponds to the JSON property maxSteps
440 441 442 |
# File 'lib/google/apis/testing_v1/classes.rb', line 440 def max_steps @max_steps end |
#robo_directives ⇒ Array<Google::Apis::TestingV1::RoboDirective>
A set of directives Robo should apply during the crawl. This allows users to
customize the crawl. For example, the username and password for a test account
can be provided.
Corresponds to the JSON property roboDirectives
447 448 449 |
# File 'lib/google/apis/testing_v1/classes.rb', line 447 def robo_directives @robo_directives end |
#robo_mode ⇒ String
The mode in which Robo should run. Most clients should allow the server to
populate this field automatically.
Corresponds to the JSON property roboMode
453 454 455 |
# File 'lib/google/apis/testing_v1/classes.rb', line 453 def robo_mode @robo_mode end |
#robo_script ⇒ Google::Apis::TestingV1::FileReference
A reference to a file, used for user inputs.
Corresponds to the JSON property roboScript
458 459 460 |
# File 'lib/google/apis/testing_v1/classes.rb', line 458 def robo_script @robo_script end |
#starting_intents ⇒ Array<Google::Apis::TestingV1::RoboStartingIntent>
The intents used to launch the app for the crawl. If none are provided, then
the main launcher activity is launched. If some are provided, then only those
provided are launched (the main launcher activity must be provided explicitly).
Corresponds to the JSON property startingIntents
465 466 467 |
# File 'lib/google/apis/testing_v1/classes.rb', line 465 def starting_intents @starting_intents end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/google/apis/testing_v1/classes.rb', line 472 def update!(**args) @app_apk = args[:app_apk] if args.key?(:app_apk) @app_bundle = args[:app_bundle] if args.key?(:app_bundle) @app_initial_activity = args[:app_initial_activity] if args.key?(:app_initial_activity) @app_package_id = args[:app_package_id] if args.key?(:app_package_id) @max_depth = args[:max_depth] if args.key?(:max_depth) @max_steps = args[:max_steps] if args.key?(:max_steps) @robo_directives = args[:robo_directives] if args.key?(:robo_directives) @robo_mode = args[:robo_mode] if args.key?(:robo_mode) @robo_script = args[:robo_script] if args.key?(:robo_script) @starting_intents = args[:starting_intents] if args.key?(:starting_intents) end |