Class: Google::Apis::TestingV1::ApkManifest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

An Android app manifest. See http://developer.android.com/guide/topics/ manifest/manifest-intro.html

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApkManifest

Returns a new instance of ApkManifest.



744
745
746
# File 'lib/google/apis/testing_v1/classes.rb', line 744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_labelString

User-readable name for the application. Corresponds to the JSON property applicationLabel

Returns:

  • (String)


682
683
684
# File 'lib/google/apis/testing_v1/classes.rb', line 682

def application_label
  @application_label
end

#intent_filtersArray<Google::Apis::TestingV1::IntentFilter>

Corresponds to the JSON property intentFilters



687
688
689
# File 'lib/google/apis/testing_v1/classes.rb', line 687

def intent_filters
  @intent_filters
end

#max_sdk_versionFixnum

Maximum API level on which the application is designed to run. Corresponds to the JSON property maxSdkVersion

Returns:

  • (Fixnum)


692
693
694
# File 'lib/google/apis/testing_v1/classes.rb', line 692

def max_sdk_version
  @max_sdk_version
end

#metadataArray<Google::Apis::TestingV1::Metadata>

Meta-data tags defined in the manifest. Corresponds to the JSON property metadata



697
698
699
# File 'lib/google/apis/testing_v1/classes.rb', line 697

def 
  @metadata
end

#min_sdk_versionFixnum

Minimum API level required for the application to run. Corresponds to the JSON property minSdkVersion

Returns:

  • (Fixnum)


702
703
704
# File 'lib/google/apis/testing_v1/classes.rb', line 702

def min_sdk_version
  @min_sdk_version
end

#package_nameString

Full Java-style package name for this application, e.g. "com.example.foo". Corresponds to the JSON property packageName

Returns:

  • (String)


707
708
709
# File 'lib/google/apis/testing_v1/classes.rb', line 707

def package_name
  @package_name
end

#servicesArray<Google::Apis::TestingV1::Service>

Services contained in the tag. Corresponds to the JSON property services



712
713
714
# File 'lib/google/apis/testing_v1/classes.rb', line 712

def services
  @services
end

#target_sdk_versionFixnum

Specifies the API Level on which the application is designed to run. Corresponds to the JSON property targetSdkVersion

Returns:

  • (Fixnum)


717
718
719
# File 'lib/google/apis/testing_v1/classes.rb', line 717

def target_sdk_version
  @target_sdk_version
end

#uses_featureArray<Google::Apis::TestingV1::UsesFeature>

Feature usage tags defined in the manifest. Corresponds to the JSON property usesFeature



722
723
724
# File 'lib/google/apis/testing_v1/classes.rb', line 722

def uses_feature
  @uses_feature
end

#uses_permissionArray<String>

Corresponds to the JSON property usesPermission

Returns:

  • (Array<String>)


727
728
729
# File 'lib/google/apis/testing_v1/classes.rb', line 727

def uses_permission
  @uses_permission
end

#uses_permission_tagsArray<Google::Apis::TestingV1::UsesPermissionTag>

Permissions declared to be used by the application Corresponds to the JSON property usesPermissionTags



732
733
734
# File 'lib/google/apis/testing_v1/classes.rb', line 732

def uses_permission_tags
  @uses_permission_tags
end

#version_codeFixnum

Version number used internally by the app. Corresponds to the JSON property versionCode

Returns:

  • (Fixnum)


737
738
739
# File 'lib/google/apis/testing_v1/classes.rb', line 737

def version_code
  @version_code
end

#version_nameString

Version number shown to users. Corresponds to the JSON property versionName

Returns:

  • (String)


742
743
744
# File 'lib/google/apis/testing_v1/classes.rb', line 742

def version_name
  @version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/google/apis/testing_v1/classes.rb', line 749

def update!(**args)
  @application_label = args[:application_label] if args.key?(:application_label)
  @intent_filters = args[:intent_filters] if args.key?(:intent_filters)
  @max_sdk_version = args[:max_sdk_version] if args.key?(:max_sdk_version)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_sdk_version = args[:min_sdk_version] if args.key?(:min_sdk_version)
  @package_name = args[:package_name] if args.key?(:package_name)
  @services = args[:services] if args.key?(:services)
  @target_sdk_version = args[:target_sdk_version] if args.key?(:target_sdk_version)
  @uses_feature = args[:uses_feature] if args.key?(:uses_feature)
  @uses_permission = args[:uses_permission] if args.key?(:uses_permission)
  @uses_permission_tags = args[:uses_permission_tags] if args.key?(:uses_permission_tags)
  @version_code = args[:version_code] if args.key?(:version_code)
  @version_name = args[:version_name] if args.key?(:version_name)
end