Class: Google::Apis::TestingV1::ApkSplits

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A single dynamic feature apk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApkSplits

Returns a new instance of ApkSplits.



778
779
780
# File 'lib/google/apis/testing_v1/classes.rb', line 778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundle_splitsArray<Google::Apis::TestingV1::FileReference>

A list of .apk files generated by bundletool to install to the device under test as a single android app with adb install-multiple. If specified, requires one or more bundle_splits. The first split specified represents the base APK, while subsequent splits represent feature apks. Corresponds to the JSON property bundleSplits



776
777
778
# File 'lib/google/apis/testing_v1/classes.rb', line 776

def bundle_splits
  @bundle_splits
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



783
784
785
# File 'lib/google/apis/testing_v1/classes.rb', line 783

def update!(**args)
  @bundle_splits = args[:bundle_splits] if args.key?(:bundle_splits)
end