Class: Google::Apis::TestingV1::AppBundle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

An Android App Bundle file format, containing a BundleConfig.pb file, a base module directory, zero or more dynamic feature module directories. See https:// developer.android.com/guide/app-bundle/build for guidance on building App Bundles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppBundle

Returns a new instance of AppBundle.



805
806
807
# File 'lib/google/apis/testing_v1/classes.rb', line 805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apksGoogle::Apis::TestingV1::ApkSplits

A single dynamic feature apk. Corresponds to the JSON property apks



798
799
800
# File 'lib/google/apis/testing_v1/classes.rb', line 798

def apks
  @apks
end

#bundle_locationGoogle::Apis::TestingV1::FileReference

A reference to a file, used for user inputs. Corresponds to the JSON property bundleLocation



803
804
805
# File 'lib/google/apis/testing_v1/classes.rb', line 803

def bundle_location
  @bundle_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



810
811
812
813
# File 'lib/google/apis/testing_v1/classes.rb', line 810

def update!(**args)
  @apks = args[:apks] if args.key?(:apks)
  @bundle_location = args[:bundle_location] if args.key?(:bundle_location)
end