Class: Google::Apis::TestingV1::DirectAccessVersionInfo
- Inherits:
-
Object
- Object
- Google::Apis::TestingV1::DirectAccessVersionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb
Overview
Denotes whether Direct Access is supported, and by which client versions. DirectAccessService is currently available as a preview to select developers. You can register today on behalf of you and your team at https://developer. android.com/studio/preview/android-device-streaming
Instance Attribute Summary collapse
-
#direct_access_supported ⇒ Boolean
(also: #direct_access_supported?)
Whether direct access is supported at all.
-
#minimum_android_studio_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DirectAccessVersionInfo
constructor
A new instance of DirectAccessVersionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DirectAccessVersionInfo
Returns a new instance of DirectAccessVersionInfo.
1124 1125 1126 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#direct_access_supported ⇒ Boolean Also known as: direct_access_supported?
Whether direct access is supported at all. Clients are expected to filter down
the device list to only android models and versions which support Direct
Access when that is the user intent.
Corresponds to the JSON property directAccessSupported
1114 1115 1116 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1114 def direct_access_supported @direct_access_supported end |
#minimum_android_studio_version ⇒ String
Output only. Indicates client-device compatibility, where a device is known to
work only with certain workarounds implemented in the Android Studio client.
Expected format "major.minor.micro.patch", e.g. "5921.22.2211.8881706".
Corresponds to the JSON property minimumAndroidStudioVersion
1122 1123 1124 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1122 def minimum_android_studio_version @minimum_android_studio_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1129 1130 1131 1132 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1129 def update!(**args) @direct_access_supported = args[:direct_access_supported] if args.key?(:direct_access_supported) @minimum_android_studio_version = args[:minimum_android_studio_version] if args.key?(:minimum_android_studio_version) end |