Class: Google::Apis::TestingV1::GetApkDetailsResponse
- Inherits:
-
Object
- Object
- Google::Apis::TestingV1::GetApkDetailsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb
Overview
Response containing the details of the specified Android application.
Instance Attribute Summary collapse
-
#apk_detail ⇒ Google::Apis::TestingV1::ApkDetail
Android application details based on application manifest and archive contents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetApkDetailsResponse
constructor
A new instance of GetApkDetailsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetApkDetailsResponse
Returns a new instance of GetApkDetailsResponse.
1293 1294 1295 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apk_detail ⇒ Google::Apis::TestingV1::ApkDetail
Android application details based on application manifest and archive contents.
Corresponds to the JSON property apkDetail
1291 1292 1293 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1291 def apk_detail @apk_detail end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1298 1299 1300 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1298 def update!(**args) @apk_detail = args[:apk_detail] if args.key?(:apk_detail) end |