Class: Google::Apis::TestingV1::GoogleAuto
- Inherits:
-
Object
- Object
- Google::Apis::TestingV1::GoogleAuto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb
Overview
Enables automatic Google account login. If set, the service automatically generates a Google test account and adds it to the device, before executing the test. Note that test accounts might be reused. Many applications show their full set of functionalities when an account is present on the device. Logging into the device with these generated accounts allows testing more functionalities.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAuto
constructor
A new instance of GoogleAuto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAuto
Returns a new instance of GoogleAuto.
1312 1313 1314 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1312 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1317 1318 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1317 def update!(**args) end |