Class: Google::Apis::TestingV1::GoogleCloudStorage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A storage location within Google cloud storage (GCS).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudStorage

Returns a new instance of GoogleCloudStorage.



1332
1333
1334
# File 'lib/google/apis/testing_v1/classes.rb', line 1332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_pathString

Required. The path to a directory in GCS that will eventually contain the results for this test. The requesting user must have write access on the bucket in the supplied path. Corresponds to the JSON property gcsPath

Returns:

  • (String)


1330
1331
1332
# File 'lib/google/apis/testing_v1/classes.rb', line 1330

def gcs_path
  @gcs_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1337
1338
1339
# File 'lib/google/apis/testing_v1/classes.rb', line 1337

def update!(**args)
  @gcs_path = args[:gcs_path] if args.key?(:gcs_path)
end