Class: Google::Apis::TestingV1::IosDeviceFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A file or directory to install on the device before the test starts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IosDeviceFile

Returns a new instance of IosDeviceFile.



1472
1473
1474
# File 'lib/google/apis/testing_v1/classes.rb', line 1472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundle_idString

The bundle id of the app where this file lives. iOS apps sandbox their own filesystem, so app files must specify which app installed on the device. Corresponds to the JSON property bundleId

Returns:

  • (String)


1460
1461
1462
# File 'lib/google/apis/testing_v1/classes.rb', line 1460

def bundle_id
  @bundle_id
end

#contentGoogle::Apis::TestingV1::FileReference

A reference to a file, used for user inputs. Corresponds to the JSON property content



1465
1466
1467
# File 'lib/google/apis/testing_v1/classes.rb', line 1465

def content
  @content
end

#device_pathString

Location of the file on the device, inside the app's sandboxed filesystem Corresponds to the JSON property devicePath

Returns:

  • (String)


1470
1471
1472
# File 'lib/google/apis/testing_v1/classes.rb', line 1470

def device_path
  @device_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1477
1478
1479
1480
1481
# File 'lib/google/apis/testing_v1/classes.rb', line 1477

def update!(**args)
  @bundle_id = args[:bundle_id] if args.key?(:bundle_id)
  @content = args[:content] if args.key?(:content)
  @device_path = args[:device_path] if args.key?(:device_path)
end