Class: Google::Apis::TestingV1::IosXcTest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A test of an iOS application that uses the XCTest framework. Xcode supports the option to "build for testing", which generates an .xctestrun file that contains a test specification (arguments, test methods, etc). This test type accepts a zip file containing the .xctestrun file and the corresponding contents of the Build/Products directory that contains all the binaries needed to run the tests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IosXcTest

Returns a new instance of IosXcTest.



1796
1797
1798
# File 'lib/google/apis/testing_v1/classes.rb', line 1796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_bundle_idString

Output only. The bundle id for the application under test. Corresponds to the JSON property appBundleId

Returns:

  • (String)


1769
1770
1771
# File 'lib/google/apis/testing_v1/classes.rb', line 1769

def app_bundle_id
  @app_bundle_id
end

#test_special_entitlementsBoolean Also known as: test_special_entitlements?

The option to test special app entitlements. Setting this would re-sign the app having special entitlements with an explicit application-identifier. Currently supports testing aps-environment entitlement. Corresponds to the JSON property testSpecialEntitlements

Returns:

  • (Boolean)


1776
1777
1778
# File 'lib/google/apis/testing_v1/classes.rb', line 1776

def test_special_entitlements
  @test_special_entitlements
end

#tests_zipGoogle::Apis::TestingV1::FileReference

A reference to a file, used for user inputs. Corresponds to the JSON property testsZip



1782
1783
1784
# File 'lib/google/apis/testing_v1/classes.rb', line 1782

def tests_zip
  @tests_zip
end

#xcode_versionString

The Xcode version that should be used for the test. Use the TestEnvironmentDiscoveryService to get supported options. Defaults to the latest Xcode version Firebase Test Lab supports. Corresponds to the JSON property xcodeVersion

Returns:

  • (String)


1789
1790
1791
# File 'lib/google/apis/testing_v1/classes.rb', line 1789

def xcode_version
  @xcode_version
end

#xctestrunGoogle::Apis::TestingV1::FileReference

A reference to a file, used for user inputs. Corresponds to the JSON property xctestrun



1794
1795
1796
# File 'lib/google/apis/testing_v1/classes.rb', line 1794

def xctestrun
  @xctestrun
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1801
1802
1803
1804
1805
1806
1807
# File 'lib/google/apis/testing_v1/classes.rb', line 1801

def update!(**args)
  @app_bundle_id = args[:app_bundle_id] if args.key?(:app_bundle_id)
  @test_special_entitlements = args[:test_special_entitlements] if args.key?(:test_special_entitlements)
  @tests_zip = args[:tests_zip] if args.key?(:tests_zip)
  @xcode_version = args[:xcode_version] if args.key?(:xcode_version)
  @xctestrun = args[:xctestrun] if args.key?(:xctestrun)
end