Class: Google::Apis::TestingV1::PerAndroidVersionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A version-specific information of an Android model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerAndroidVersionInfo

Returns a new instance of PerAndroidVersionInfo.



2143
2144
2145
# File 'lib/google/apis/testing_v1/classes.rb', line 2143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_capacityString

The number of online devices for an Android version. Corresponds to the JSON property deviceCapacity

Returns:

  • (String)


2122
2123
2124
# File 'lib/google/apis/testing_v1/classes.rb', line 2122

def device_capacity
  @device_capacity
end

#direct_access_version_infoGoogle::Apis::TestingV1::DirectAccessVersionInfo

Denotes whether Direct Access is supported, and by which client versions. DirectAccessService is currently available as a preview to select developers. You can register today on behalf of you and your team at https://developer. android.com/studio/preview/android-device-streaming Corresponds to the JSON property directAccessVersionInfo



2130
2131
2132
# File 'lib/google/apis/testing_v1/classes.rb', line 2130

def direct_access_version_info
  @direct_access_version_info
end

#interactive_device_availability_estimateString

Output only. The estimated wait time for a single interactive device session using Direct Access. Corresponds to the JSON property interactiveDeviceAvailabilityEstimate

Returns:

  • (String)


2136
2137
2138
# File 'lib/google/apis/testing_v1/classes.rb', line 2136

def interactive_device_availability_estimate
  @interactive_device_availability_estimate
end

#version_idString

An Android version. Corresponds to the JSON property versionId

Returns:

  • (String)


2141
2142
2143
# File 'lib/google/apis/testing_v1/classes.rb', line 2141

def version_id
  @version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2148
2149
2150
2151
2152
2153
# File 'lib/google/apis/testing_v1/classes.rb', line 2148

def update!(**args)
  @device_capacity = args[:device_capacity] if args.key?(:device_capacity)
  @direct_access_version_info = args[:direct_access_version_info] if args.key?(:direct_access_version_info)
  @interactive_device_availability_estimate = args[:interactive_device_availability_estimate] if args.key?(:interactive_device_availability_estimate)
  @version_id = args[:version_id] if args.key?(:version_id)
end