Class: Google::Apis::TestingV1::RegularFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A file or directory to install on the device before the test starts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegularFile

Returns a new instance of RegularFile.



2235
2236
2237
# File 'lib/google/apis/testing_v1/classes.rb', line 2235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::TestingV1::FileReference

A reference to a file, used for user inputs. Corresponds to the JSON property content



2218
2219
2220
# File 'lib/google/apis/testing_v1/classes.rb', line 2218

def content
  @content
end

#device_pathString

Required. Where to put the content on the device. Must be an absolute, allowlisted path. If the file exists, it will be replaced. The following device-side directories and any of their subdirectories are allowlisted: $ EXTERNAL_STORAGE, /sdcard $ANDROID_DATA/local/tmp, or /data/local/tmp Specifying a path outside of these directory trees is invalid. The paths / sdcard and /data will be made available and treated as implicit path substitutions. E.g. if /sdcard on a particular device does not map to external storage, the system will replace it with the external storage path prefix for that device and copy the file there. It is strongly advised to use the Environment API in app and test code to access files on the device in a portable way. Corresponds to the JSON property devicePath

Returns:

  • (String)


2233
2234
2235
# File 'lib/google/apis/testing_v1/classes.rb', line 2233

def device_path
  @device_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2240
2241
2242
2243
# File 'lib/google/apis/testing_v1/classes.rb', line 2240

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @device_path = args[:device_path] if args.key?(:device_path)
end