Class: Google::Apis::TestingV1::RoboStartingIntent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

Message for specifying the start activities to crawl.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoboStartingIntent

Returns a new instance of RoboStartingIntent.



2344
2345
2346
# File 'lib/google/apis/testing_v1/classes.rb', line 2344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#launcher_activityGoogle::Apis::TestingV1::LauncherActivityIntent

Specifies an intent that starts the main launcher activity. Corresponds to the JSON property launcherActivity



2327
2328
2329
# File 'lib/google/apis/testing_v1/classes.rb', line 2327

def launcher_activity
  @launcher_activity
end

#no_activityGoogle::Apis::TestingV1::NoActivityIntent

Skips the starting activity Corresponds to the JSON property noActivity



2332
2333
2334
# File 'lib/google/apis/testing_v1/classes.rb', line 2332

def no_activity
  @no_activity
end

#start_activityGoogle::Apis::TestingV1::StartActivityIntent

A starting intent specified by an action, uri, and categories. Corresponds to the JSON property startActivity



2337
2338
2339
# File 'lib/google/apis/testing_v1/classes.rb', line 2337

def start_activity
  @start_activity
end

#timeoutString

Timeout in seconds for each intent. Corresponds to the JSON property timeout

Returns:

  • (String)


2342
2343
2344
# File 'lib/google/apis/testing_v1/classes.rb', line 2342

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2349
2350
2351
2352
2353
2354
# File 'lib/google/apis/testing_v1/classes.rb', line 2349

def update!(**args)
  @launcher_activity = args[:launcher_activity] if args.key?(:launcher_activity)
  @no_activity = args[:no_activity] if args.key?(:no_activity)
  @start_activity = args[:start_activity] if args.key?(:start_activity)
  @timeout = args[:timeout] if args.key?(:timeout)
end