Class: Google::Apis::TestingV1::SessionStateEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A message encapsulating a series of Session states and the time that the DeviceSession first entered those states.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionStateEvent

Returns a new instance of SessionStateEvent.



2403
2404
2405
# File 'lib/google/apis/testing_v1/classes.rb', line 2403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_timeString

Output only. The time that the session_state first encountered that state. Corresponds to the JSON property eventTime

Returns:

  • (String)


2391
2392
2393
# File 'lib/google/apis/testing_v1/classes.rb', line 2391

def event_time
  @event_time
end

#session_stateString

Output only. The session_state tracked by this event Corresponds to the JSON property sessionState

Returns:

  • (String)


2396
2397
2398
# File 'lib/google/apis/testing_v1/classes.rb', line 2396

def session_state
  @session_state
end

#state_messageString

Output only. A human-readable message to explain the state. Corresponds to the JSON property stateMessage

Returns:

  • (String)


2401
2402
2403
# File 'lib/google/apis/testing_v1/classes.rb', line 2401

def state_message
  @state_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2408
2409
2410
2411
2412
# File 'lib/google/apis/testing_v1/classes.rb', line 2408

def update!(**args)
  @event_time = args[:event_time] if args.key?(:event_time)
  @session_state = args[:session_state] if args.key?(:session_state)
  @state_message = args[:state_message] if args.key?(:state_message)
end