Class: Google::Apis::TestingV1::TestMatrix

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

TestMatrix captures all details about a test. It contains the environment configuration, test specification, test executions and overall state and outcome.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestMatrix

Returns a new instance of TestMatrix.



2820
2821
2822
# File 'lib/google/apis/testing_v1/classes.rb', line 2820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_infoGoogle::Apis::TestingV1::ClientInfo

Information about the client which invoked the test. Corresponds to the JSON property clientInfo



2740
2741
2742
# File 'lib/google/apis/testing_v1/classes.rb', line 2740

def client_info
  @client_info
end

#environment_matrixGoogle::Apis::TestingV1::EnvironmentMatrix

The matrix of environments in which the test is to be executed. Corresponds to the JSON property environmentMatrix



2745
2746
2747
# File 'lib/google/apis/testing_v1/classes.rb', line 2745

def environment_matrix
  @environment_matrix
end

#extended_invalid_matrix_detailsArray<Google::Apis::TestingV1::MatrixErrorDetail>

Output only. Details about why a matrix was deemed invalid. If multiple checks can be safely performed, they will be reported but no assumptions should be made about the length of this list. Corresponds to the JSON property extendedInvalidMatrixDetails



2752
2753
2754
# File 'lib/google/apis/testing_v1/classes.rb', line 2752

def extended_invalid_matrix_details
  @extended_invalid_matrix_details
end

#fail_fastBoolean Also known as: fail_fast?

If true, only a single attempt at most will be made to run each execution/ shard in the matrix. Flaky test attempts are not affected. Normally, 2 or more attempts are made if a potential infrastructure issue is detected. This feature is for latency sensitive workloads. The incidence of execution failures may be significantly greater for fail-fast matrices and support is more limited because of that expectation. Corresponds to the JSON property failFast

Returns:

  • (Boolean)


2762
2763
2764
# File 'lib/google/apis/testing_v1/classes.rb', line 2762

def fail_fast
  @fail_fast
end

#flaky_test_attemptsFixnum

The number of times a TestExecution should be re-attempted if one or more of its test cases fail for any reason. The maximum number of reruns allowed is 10. Default is 0, which implies no reruns. Corresponds to the JSON property flakyTestAttempts

Returns:

  • (Fixnum)


2770
2771
2772
# File 'lib/google/apis/testing_v1/classes.rb', line 2770

def flaky_test_attempts
  @flaky_test_attempts
end

#invalid_matrix_detailsString

Output only. Describes why the matrix is considered invalid. Only useful for matrices in the INVALID state. Corresponds to the JSON property invalidMatrixDetails

Returns:

  • (String)


2776
2777
2778
# File 'lib/google/apis/testing_v1/classes.rb', line 2776

def invalid_matrix_details
  @invalid_matrix_details
end

#outcome_summaryString

Output Only. The overall outcome of the test. Only set when the test matrix state is FINISHED. Corresponds to the JSON property outcomeSummary

Returns:

  • (String)


2782
2783
2784
# File 'lib/google/apis/testing_v1/classes.rb', line 2782

def outcome_summary
  @outcome_summary
end

#project_idString

The cloud project that owns the test matrix. Corresponds to the JSON property projectId

Returns:

  • (String)


2787
2788
2789
# File 'lib/google/apis/testing_v1/classes.rb', line 2787

def project_id
  @project_id
end

#result_storageGoogle::Apis::TestingV1::ResultStorage

Locations where the results of running the test are stored. Corresponds to the JSON property resultStorage



2792
2793
2794
# File 'lib/google/apis/testing_v1/classes.rb', line 2792

def result_storage
  @result_storage
end

#stateString

Output only. Indicates the current progress of the test matrix. Corresponds to the JSON property state

Returns:

  • (String)


2797
2798
2799
# File 'lib/google/apis/testing_v1/classes.rb', line 2797

def state
  @state
end

#test_executionsArray<Google::Apis::TestingV1::TestExecution>

Output only. The list of test executions that the service creates for this matrix. Corresponds to the JSON property testExecutions



2803
2804
2805
# File 'lib/google/apis/testing_v1/classes.rb', line 2803

def test_executions
  @test_executions
end

#test_matrix_idString

Output only. Unique id set by the service. Corresponds to the JSON property testMatrixId

Returns:

  • (String)


2808
2809
2810
# File 'lib/google/apis/testing_v1/classes.rb', line 2808

def test_matrix_id
  @test_matrix_id
end

#test_specificationGoogle::Apis::TestingV1::TestSpecification

A description of how to run the test. Corresponds to the JSON property testSpecification



2813
2814
2815
# File 'lib/google/apis/testing_v1/classes.rb', line 2813

def test_specification
  @test_specification
end

#timestampString

Output only. The time this test matrix was initially created. Corresponds to the JSON property timestamp

Returns:

  • (String)


2818
2819
2820
# File 'lib/google/apis/testing_v1/classes.rb', line 2818

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
# File 'lib/google/apis/testing_v1/classes.rb', line 2825

def update!(**args)
  @client_info = args[:client_info] if args.key?(:client_info)
  @environment_matrix = args[:environment_matrix] if args.key?(:environment_matrix)
  @extended_invalid_matrix_details = args[:extended_invalid_matrix_details] if args.key?(:extended_invalid_matrix_details)
  @fail_fast = args[:fail_fast] if args.key?(:fail_fast)
  @flaky_test_attempts = args[:flaky_test_attempts] if args.key?(:flaky_test_attempts)
  @invalid_matrix_details = args[:invalid_matrix_details] if args.key?(:invalid_matrix_details)
  @outcome_summary = args[:outcome_summary] if args.key?(:outcome_summary)
  @project_id = args[:project_id] if args.key?(:project_id)
  @result_storage = args[:result_storage] if args.key?(:result_storage)
  @state = args[:state] if args.key?(:state)
  @test_executions = args[:test_executions] if args.key?(:test_executions)
  @test_matrix_id = args[:test_matrix_id] if args.key?(:test_matrix_id)
  @test_specification = args[:test_specification] if args.key?(:test_specification)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end