Class: Google::Apis::TestingV1::TestSetup
- Inherits:
-
Object
- Object
- Google::Apis::TestingV1::TestSetup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb
Overview
A description of how to set up the Android device prior to running the test.
Instance Attribute Summary collapse
-
#account ⇒ Google::Apis::TestingV1::Account
Identifies an account and how to log into it.
-
#additional_apks ⇒ Array<Google::Apis::TestingV1::Apk>
APKs to install in addition to those being directly tested.
-
#directories_to_pull ⇒ Array<String>
List of directories on the device to upload to GCS at the end of the test; they must be absolute paths under /sdcard, /storage or /data/local/tmp.
-
#dont_autogrant_permissions ⇒ Boolean
(also: #dont_autogrant_permissions?)
Whether to prevent all runtime permissions to be granted at app install Corresponds to the JSON property
dontAutograntPermissions. -
#environment_variables ⇒ Array<Google::Apis::TestingV1::EnvironmentVariable>
Environment variables to set for the test (only applicable for instrumentation tests).
-
#files_to_push ⇒ Array<Google::Apis::TestingV1::DeviceFile>
List of files to push to the device before starting the test.
-
#initial_setup_apks ⇒ Array<Google::Apis::TestingV1::Apk>
Optional.
-
#network_profile ⇒ String
The network traffic profile used for running the test.
-
#systrace ⇒ Google::Apis::TestingV1::SystraceSetup
Systrace configuration for the run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestSetup
constructor
A new instance of TestSetup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestSetup
Returns a new instance of TestSetup.
2907 2908 2909 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account ⇒ Google::Apis::TestingV1::Account
Identifies an account and how to log into it.
Corresponds to the JSON property account
2850 2851 2852 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2850 def account @account end |
#additional_apks ⇒ Array<Google::Apis::TestingV1::Apk>
APKs to install in addition to those being directly tested. These will be
installed after the app under test. Limited to a combined total of 100 initial
setup and additional files.
Corresponds to the JSON property additionalApks
2857 2858 2859 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2857 def additional_apks @additional_apks end |
#directories_to_pull ⇒ Array<String>
List of directories on the device to upload to GCS at the end of the test;
they must be absolute paths under /sdcard, /storage or /data/local/tmp. Path
names are restricted to characters a-z A-Z 0-9 _ - . + and / Note: The paths /
sdcard and /data will be made available and treated as implicit path
substitutions. E.g. if /sdcard on a particular device does not map to external
storage, the system will replace it with the external storage path prefix for
that device.
Corresponds to the JSON property directoriesToPull
2868 2869 2870 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2868 def directories_to_pull @directories_to_pull end |
#dont_autogrant_permissions ⇒ Boolean Also known as: dont_autogrant_permissions?
Whether to prevent all runtime permissions to be granted at app install
Corresponds to the JSON property dontAutograntPermissions
2873 2874 2875 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2873 def @dont_autogrant_permissions end |
#environment_variables ⇒ Array<Google::Apis::TestingV1::EnvironmentVariable>
Environment variables to set for the test (only applicable for instrumentation
tests).
Corresponds to the JSON property environmentVariables
2880 2881 2882 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2880 def environment_variables @environment_variables end |
#files_to_push ⇒ Array<Google::Apis::TestingV1::DeviceFile>
List of files to push to the device before starting the test.
Corresponds to the JSON property filesToPush
2885 2886 2887 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2885 def files_to_push @files_to_push end |
#initial_setup_apks ⇒ Array<Google::Apis::TestingV1::Apk>
Optional. Initial setup APKs to install before the app under test is installed.
Limited to a combined total of 100 initial setup and additional files.
Corresponds to the JSON property initialSetupApks
2891 2892 2893 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2891 def initial_setup_apks @initial_setup_apks end |
#network_profile ⇒ String
The network traffic profile used for running the test. Available network
profiles can be queried by using the NETWORK_CONFIGURATION environment type
when calling TestEnvironmentDiscoveryService.GetTestEnvironmentCatalog.
Corresponds to the JSON property networkProfile
2898 2899 2900 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2898 def network_profile @network_profile end |
#systrace ⇒ Google::Apis::TestingV1::SystraceSetup
Systrace configuration for the run. Deprecated: Systrace used Python 2 which
was sunsetted on 2020-01-01. Systrace is no longer supported in the Cloud
Testing API, and no Systrace file will be provided in the results.
Corresponds to the JSON property systrace
2905 2906 2907 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2905 def systrace @systrace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 |
# File 'lib/google/apis/testing_v1/classes.rb', line 2912 def update!(**args) @account = args[:account] if args.key?(:account) @additional_apks = args[:additional_apks] if args.key?(:additional_apks) @directories_to_pull = args[:directories_to_pull] if args.key?(:directories_to_pull) @dont_autogrant_permissions = args[:dont_autogrant_permissions] if args.key?(:dont_autogrant_permissions) @environment_variables = args[:environment_variables] if args.key?(:environment_variables) @files_to_push = args[:files_to_push] if args.key?(:files_to_push) @initial_setup_apks = args[:initial_setup_apks] if args.key?(:initial_setup_apks) @network_profile = args[:network_profile] if args.key?(:network_profile) @systrace = args[:systrace] if args.key?(:systrace) end |