Class: Google::Apis::TestingV1::TestSpecification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb

Overview

A description of how to run the test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestSpecification

Returns a new instance of TestSpecification.



3001
3002
3003
# File 'lib/google/apis/testing_v1/classes.rb', line 3001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_instrumentation_testGoogle::Apis::TestingV1::AndroidInstrumentationTest

A test of an Android application that can control an Android component independently of its normal lifecycle. Android instrumentation tests run an application APK and test APK inside the same process on a virtual or physical AndroidDevice. They also specify a test runner class, such as com.google. GoogleTestRunner, which can vary on the specific instrumentation framework chosen. See for more information on types of Android tests. Corresponds to the JSON property androidInstrumentationTest



2937
2938
2939
# File 'lib/google/apis/testing_v1/classes.rb', line 2937

def android_instrumentation_test
  @android_instrumentation_test
end

#android_robo_testGoogle::Apis::TestingV1::AndroidRoboTest

A test of an android application that explores the application on a virtual or physical Android Device, finding culprits and crashes as it goes. Corresponds to the JSON property androidRoboTest



2943
2944
2945
# File 'lib/google/apis/testing_v1/classes.rb', line 2943

def android_robo_test
  @android_robo_test
end

#android_test_loopGoogle::Apis::TestingV1::AndroidTestLoop

A test of an Android Application with a Test Loop. The intent \ will be implicitly added, since Games is the only user of this api, for the time being. Corresponds to the JSON property androidTestLoop



2949
2950
2951
# File 'lib/google/apis/testing_v1/classes.rb', line 2949

def android_test_loop
  @android_test_loop
end

#disable_performance_metricsBoolean Also known as: disable_performance_metrics?

Disables performance metrics recording. May reduce test latency. Corresponds to the JSON property disablePerformanceMetrics

Returns:

  • (Boolean)


2954
2955
2956
# File 'lib/google/apis/testing_v1/classes.rb', line 2954

def disable_performance_metrics
  @disable_performance_metrics
end

#disable_video_recordingBoolean Also known as: disable_video_recording?

Disables video recording. May reduce test latency. Corresponds to the JSON property disableVideoRecording

Returns:

  • (Boolean)


2960
2961
2962
# File 'lib/google/apis/testing_v1/classes.rb', line 2960

def disable_video_recording
  @disable_video_recording
end

#ios_robo_testGoogle::Apis::TestingV1::IosRoboTest

A test that explores an iOS application on an iOS device. Corresponds to the JSON property iosRoboTest



2966
2967
2968
# File 'lib/google/apis/testing_v1/classes.rb', line 2966

def ios_robo_test
  @ios_robo_test
end

#ios_test_loopGoogle::Apis::TestingV1::IosTestLoop

A test of an iOS application that implements one or more game loop scenarios. This test type accepts an archived application (.ipa file) and a list of integer scenarios that will be executed on the app sequentially. Corresponds to the JSON property iosTestLoop



2973
2974
2975
# File 'lib/google/apis/testing_v1/classes.rb', line 2973

def ios_test_loop
  @ios_test_loop
end

#ios_test_setupGoogle::Apis::TestingV1::IosTestSetup

A description of how to set up an iOS device prior to running the test. Corresponds to the JSON property iosTestSetup



2978
2979
2980
# File 'lib/google/apis/testing_v1/classes.rb', line 2978

def ios_test_setup
  @ios_test_setup
end

#ios_xc_testGoogle::Apis::TestingV1::IosXcTest

A test of an iOS application that uses the XCTest framework. Xcode supports the option to "build for testing", which generates an .xctestrun file that contains a test specification (arguments, test methods, etc). This test type accepts a zip file containing the .xctestrun file and the corresponding contents of the Build/Products directory that contains all the binaries needed to run the tests. Corresponds to the JSON property iosXcTest



2988
2989
2990
# File 'lib/google/apis/testing_v1/classes.rb', line 2988

def ios_xc_test
  @ios_xc_test
end

#test_setupGoogle::Apis::TestingV1::TestSetup

A description of how to set up the Android device prior to running the test. Corresponds to the JSON property testSetup



2993
2994
2995
# File 'lib/google/apis/testing_v1/classes.rb', line 2993

def test_setup
  @test_setup
end

#test_timeoutString

Max time a test execution is allowed to run before it is automatically cancelled. The default value is 5 min. Corresponds to the JSON property testTimeout

Returns:

  • (String)


2999
3000
3001
# File 'lib/google/apis/testing_v1/classes.rb', line 2999

def test_timeout
  @test_timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
# File 'lib/google/apis/testing_v1/classes.rb', line 3006

def update!(**args)
  @android_instrumentation_test = args[:android_instrumentation_test] if args.key?(:android_instrumentation_test)
  @android_robo_test = args[:android_robo_test] if args.key?(:android_robo_test)
  @android_test_loop = args[:android_test_loop] if args.key?(:android_test_loop)
  @disable_performance_metrics = args[:disable_performance_metrics] if args.key?(:disable_performance_metrics)
  @disable_video_recording = args[:disable_video_recording] if args.key?(:disable_video_recording)
  @ios_robo_test = args[:ios_robo_test] if args.key?(:ios_robo_test)
  @ios_test_loop = args[:ios_test_loop] if args.key?(:ios_test_loop)
  @ios_test_setup = args[:ios_test_setup] if args.key?(:ios_test_setup)
  @ios_xc_test = args[:ios_xc_test] if args.key?(:ios_xc_test)
  @test_setup = args[:test_setup] if args.key?(:test_setup)
  @test_timeout = args[:test_timeout] if args.key?(:test_timeout)
end