Class: Google::Apis::TestingV1::DeviceSession
- Inherits:
-
Object
- Object
- Google::Apis::TestingV1::DeviceSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb
Overview
Protobuf message describing the device message, used from several RPCs.
Instance Attribute Summary collapse
-
#active_start_time ⇒ String
Output only.
-
#android_device ⇒ Google::Apis::TestingV1::AndroidDevice
A single Android device.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#expire_time ⇒ String
Optional.
-
#inactivity_timeout ⇒ String
Output only.
-
#name ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#state_histories ⇒ Array<Google::Apis::TestingV1::SessionStateEvent>
Output only.
-
#ttl ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceSession
constructor
A new instance of DeviceSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceSession
Returns a new instance of DeviceSession.
1083 1084 1085 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_start_time ⇒ String
Output only. The timestamp that the session first became ACTIVE.
Corresponds to the JSON property activeStartTime
1030 1031 1032 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1030 def active_start_time @active_start_time end |
#android_device ⇒ Google::Apis::TestingV1::AndroidDevice
A single Android device.
Corresponds to the JSON property androidDevice
1035 1036 1037 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1035 def android_device @android_device end |
#create_time ⇒ String
Output only. The time that the Session was created.
Corresponds to the JSON property createTime
1040 1041 1042 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1040 def create_time @create_time end |
#display_name ⇒ String
Output only. The title of the DeviceSession to be presented in the UI.
Corresponds to the JSON property displayName
1045 1046 1047 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1045 def display_name @display_name end |
#expire_time ⇒ String
Optional. If the device is still in use at this time, any connections will be
ended and the SessionState will transition from ACTIVE to FINISHED.
Corresponds to the JSON property expireTime
1051 1052 1053 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1051 def expire_time @expire_time end |
#inactivity_timeout ⇒ String
Output only. The interval of time that this device must be interacted with
before it transitions from ACTIVE to TIMEOUT_INACTIVITY.
Corresponds to the JSON property inactivityTimeout
1057 1058 1059 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1057 def inactivity_timeout @inactivity_timeout end |
#name ⇒ String
Optional. Name of the DeviceSession, e.g. "projects/project_id/
deviceSessions/session_id"
Corresponds to the JSON property name
1063 1064 1065 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1063 def name @name end |
#state ⇒ String
Output only. Current state of the DeviceSession.
Corresponds to the JSON property state
1068 1069 1070 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1068 def state @state end |
#state_histories ⇒ Array<Google::Apis::TestingV1::SessionStateEvent>
Output only. The historical state transitions of the session_state message
including the current session state.
Corresponds to the JSON property stateHistories
1074 1075 1076 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1074 def state_histories @state_histories end |
#ttl ⇒ String
Optional. The amount of time that a device will be initially allocated for.
This can eventually be extended with the UpdateDeviceSession RPC. Default: 15
minutes.
Corresponds to the JSON property ttl
1081 1082 1083 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1081 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1088 def update!(**args) @active_start_time = args[:active_start_time] if args.key?(:active_start_time) @android_device = args[:android_device] if args.key?(:android_device) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @inactivity_timeout = args[:inactivity_timeout] if args.key?(:inactivity_timeout) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @state_histories = args[:state_histories] if args.key?(:state_histories) @ttl = args[:ttl] if args.key?(:ttl) end |