Class: Google::Apis::TestingV1::MatrixErrorDetail
- Inherits:
-
Object
- Object
- Google::Apis::TestingV1::MatrixErrorDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/testing_v1/classes.rb,
lib/google/apis/testing_v1/representations.rb,
lib/google/apis/testing_v1/representations.rb
Overview
Describes a single error or issue with a matrix.
Instance Attribute Summary collapse
-
#message ⇒ String
Output only.
-
#reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MatrixErrorDetail
constructor
A new instance of MatrixErrorDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MatrixErrorDetail
Returns a new instance of MatrixErrorDetail.
1957 1958 1959 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Output only. A human-readable message about how the error in the TestMatrix.
Expands on the reason field with additional details and possible options to
fix the issue.
Corresponds to the JSON property message
1949 1950 1951 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1949 def @message end |
#reason ⇒ String
Output only. The reason for the error. This is a constant value in
UPPER_SNAKE_CASE that identifies the cause of the error.
Corresponds to the JSON property reason
1955 1956 1957 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1955 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1962 1963 1964 1965 |
# File 'lib/google/apis/testing_v1/classes.rb', line 1962 def update!(**args) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) end |